<?php

namespace Drupal\domain_perm\Config;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;
use Drupal\Core\Site\Settings;

/**
 * Override this class as needed. Or just make your own class.
 */
class ConfigOverride implements ConfigFactoryOverrideInterface {

  /**
   * Blank out the permissions for higher role(s) if not matching an edit domain.
   */
  public function loadOverrides($names) {
    $overrides = [];
    // Use the Setting below to identify roles that are exempt from blanking.
    $roles_exempt = Settings::get('domain_perm_roles_exempt', ['anonymous', 'authenticated']);
    $roles_exempt_config_names = array_map(function($val) { return "user.role.$val";}, $roles_exempt);
    foreach ($names as $name) {
      if (str_starts_with($name, 'user.role.') && !in_array($name, $roles_exempt_config_names) && !$this->isEditDomain()) {
        $overrides[$name] = ['permissions' => new \EmptyIterator(), 'is_admin' => FALSE];
      }
    }
    return $overrides;
  }

  public function getCacheSuffix() {
    return 'domain_perm.config_override.' . $this->isEditDomain();
  }

  /**
   * This context ensures that all render caching has the domain as cache key.
   */
  public function getCacheableMetadata($name) {
    return (new CacheableMetadata())->addCacheContexts(['url.site']);
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

  public function isEditDomain(): bool {
    return str_contains(\Drupal::request()->getHost(), '-content');
  }

}
